/* the symbol table definitions */
%{
#include "attack_parser.h"
#include "parser.h"

YY_BUFFER_STATE bufstate;

int parse_line(char *str) {
    int ret;
    
    yy_scan_string (str);
    ret = yyparse();
    yy_delete_buffer(YY_CURRENT_BUFFER);

    return ret;
}

%}

%option noyywrap

MONTH       (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)
DAYNO       [1-9][0-9]?
HOUR        (0|1)[0-9]|2[0-4]
MINPS       [0-5][0-9]
WORD        [a-zA-Z0-9][-_a-zA-Z0-9]+
NUMBER      [1-9][0-9]*
%%

 /* SSH: invalid or rejected user (cross platform [generated by openssh]) */
"Invalid user "[^ ]+" from "                                    { return SSH_INVALUSERPREF; }
"User "[^ ]+" from "                                            { return SSH_NOTALLOWEDPREF; }
" not allowed because ".+                                       { return SSH_NOTALLOWEDSUFF; }

 /* SSH: authentication error (user OK, password KO) */
"Failed "[^ ]+" for "(invalid\ user\ )?[^ ]+" from "            { return SSH_LOGINERR_PREF; }
"port "{NUMBER}" ssh".?                                         { return SSH_LOGINERR_SUFF; }

 /* dovecot */
"imap-login: Aborted login ("{NUMBER}" authentication attempts): user="[^ ]+" method="[^ ]+" rip="[^ ]+" lip="  { return DOVECOT_IMAP_LOGINERR_PREF; }
", secured"                                                     { return DOVECOT_IMAP_LOGINERR_SUFF; }

 /* UWimap login errors */
"Login failed user="[^ ]+" auth="[^ ]*" host="[^ ]+" "          { return UWIMAP_LOGINERR; }

 /* FreeBSD's ftpd login errors */
"FTP LOGIN FAILED FROM "                                        { return FREEBSDFTPD_LOGINERR_PREF; }
", ".+                                                          { return FREEBSDFTPD_LOGINERR_SUFF; }

 /* ProFTPd */
({WORD}\.)+{WORD}" ("[^\[]+"["                                              { return PROFTPD_LOGINERR_PREF; }
"]) - no such user ".+                                          { return PROFTPD_LOGINERR_SUFF; }

 /* Pure-FTPd */
"("[^@]+"@"                                                     { return PUREFTPD_LOGINERR_PREF; }
") [WARNING] Authentication failed for user ".+                 { return PUREFTPD_LOGINERR_SUFF; }


 /**         COMMON-USE TOKENS       do not touch these          **/
 /* an IPv4 address */
(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]([0-9])?)(\.(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]([0-9])?|0)){3} { yylval.str = yytext; return IPv4; }
 /* an IPv6 address */
(([a-fA-F0-9]{1,4}(:[a-fA-F0-9]{1,4}){7})|(([a-fA-F0-9]{1,4}:){2}(:[a-fA-F0-9]{1,4}){1,5})|(:(:[a-fA-F0-9]{1,4}){1,6}|([a-fA-F0-9]{1,4}:)(:[a-fA-F0-9]{1,4}){1,6}|([a-fA-F0-9]{1,4}:){2}(:[a-fA-F0-9]{1,4}){1,5}|([a-fA-F0-9]{1,4}:){3}(:[a-fA-F0-9]{1,4}){1,4}|([a-fA-F0-9]{1,4}:){4}(:[a-fA-F0-9]{1,4}){1,3}|([a-fA-F0-9]{1,4}:){5}(:[a-fA-F0-9]{1,4}){1,2}|([a-fA-F0-9]{1,4}:){6}:[a-fA-F0-9]{1,4}))           { yylval.str = yytext; return IPv6;  }

 /* an host address (PTR) */
localhost|([-a-zA-Z0-9]+\.)+[a-zA-Z]+                           { yylval.str = yytext; return HOSTADDR; }
{NUMBER}                                                        { yylval.num = (int)strtol(yytext, (char **)NULL, 10); return INTEGER; }
 /* syslog timestamp */
{MONTH}\ +{DAYNO}\ +{HOUR}:{MINPS}:{MINPS}                      { return TIMESTAMP_SYSLOG; }
 /* TAI64 timestamp */
[0-9A-Fa-f]{8}                                                  { return TIMESTAMP_TAI64; }

[^ :]+:[^ ]+                                                    { return FACILITYPRIORITY; }
{WORD}                                                          { yylval.str = yytext; return WORD; }
[ \n\t]+            /* eat blanks */
 /* literals */
 /*\n                                                              { return NEWLINE; } */
.                                                               { return yytext[0]; }

 /**         end of COMMON-USE TOKENS                           **/

